@@ -5,6 +5,7 @@ from IPython.display import display, clear_output
 import ipywidgets as widgets
 import numpy as np
 from clease_gui import utils, register_logger
+from clease_gui.app_data import Notification, AppDataKeys
 from clease_gui.widget_collection import WidgetCollection, SingleWidget
 
 logger = logging.getLogger(__name__)
@@ -207,14 +208,16 @@ class CommonSettingsButtons(MaxClusterWidget, WidgetCollection, ABC):
         widget_lst.append(SingleWidget("basis_func_type", basis_func_type, priority=100))
 
         # include background atoms
-        include_background_atoms = widgets.Dropdown(
+        self.include_background_atoms = widgets.Dropdown(
             options=[("True", True), ("False", False)],
             value=False,
             description="Background atoms:",
             **self.DEFAULT_STYLE_KWARGS,
         )
+        # Ensure that include_background_atoms is only enabled when no settings are present
+        self.app_data.subscribe(AppDataKeys.SETTINGS, self._on_settings_change)
         widget_lst.append(
-            SingleWidget("include_background_atoms", include_background_atoms, priority=5)
+            SingleWidget("include_background_atoms", self.include_background_atoms, priority=5)
         )
 
         # db_name
@@ -234,6 +237,13 @@ class CommonSettingsButtons(MaxClusterWidget, WidgetCollection, ABC):
             return widget.widget.value
         return super().get_widget_value(widget)
 
+    def _on_settings_change(self, change: Notification) -> None:
+        if change.key == AppDataKeys.SETTINGS:
+            # Update is_background_atoms widget state
+            is_disabled = change.new_value is not None
+            logger.debug("Updating is_background_atoms to: %s", is_disabled)
+            self.include_background_atoms.disabled = is_disabled
+
 
 class CrystalButtons(WidgetCollection, ABC):
     def __init__(self, app_data, *args, **kwargs):
