@@ -121,11 +121,16 @@ class SupercellDashboard(BaseDashboard):
             self._update_desc_label()
 
     def _visualize_supercell(self):
+        from ase.visualize import view
+
         supercell = self.supercell
         if supercell is None:
             raise ValueError("No supercell has been made yet.")
-        gui = utils.make_ase_gui(supercell)
-        gui.run()
+        # use a copy to remove any energies, we don't want to see graphs
+        # this is a bit of a hack...
+        cpy = supercell.copy()
+        cpy.calc = None
+        view(cpy)
         logger.info("Opened supercell in a new ASE GUI window.")
 
     def make_desc_label(self):
